"""Project configuration file."""
import sys

"""mysql database configuration """
DB_HOST = sys.modules['DB_HOST']
DB_USER = sys.modules['DB_USER']
DB_PASSWORD = sys.modules['DB_PASSWORD']
DB_PORT = sys.modules['DB_PORT']
DB_NAME = sys.modules['DB_NAME']
DB_CHARSET = sys.modules['DB_CHARSET']

"""request expiration time, unit: second"""
TIME_OUT = sys.modules['TIME_OUT']

"""roxy user-agent"""
HEADERS = sys.modules['HEADERS']

"""
proxy ip:
The proxy ip is randomly obtained through the PROXIES list. If it is not enabled, the real ip is used.
"""
#PROXIES = sys.modules['PROXIES']

"""
absolute path of phantomjs:
If you do not need to get the webpage after javascript is running, you can ignore this.
"""
PHANTOMJS = sys.modules['PHANTOMJS']

"""webdriver waits for the page to finish loading, unit: second"""
WAIT_TIME = sys.modules['WAIT_TIME']

"""project execution log directory"""
LOG_DIR = sys.modules['LOG_DIR']

"""excel file directory"""
EXCEL_DIR = sys.modules['EXCEL_DIR']



"""Project configuration file."""
import sys

"""mysql database configuration """
sys.modules['DB_HOST'] = 'localhost'
sys.modules['DB_USER'] = 'root'
sys.modules['DB_PASSWORD'] = 'root'
sys.modules['DB_PORT'] = 3306
sys.modules['DB_NAME'] = 'spider'
sys.modules['DB_CHARSET'] = 'utf8'

"""request expiration time, unit: second"""
sys.modules['TIME_OUT'] = 10

"""roxy user-agent"""
sys.modules['HEADERS'] = [{'User-Agent':'Mozilla/5.0 (Windows NT 6.1; W) Gecko/20100101 Firefox/59.0'}]

"""
proxy ip:
The proxy ip is randomly obtained through the PROXIES list. If it is not enabled, the real ip is used.
"""
#sys.modules['PROXIES'] = [{'http':'61.136.163.245:8103'}]

"""
absolute path of phantomjs:
If you do not need to get the webpage after javascript is running, you can ignore this.
"""
sys.modules['PHANTOMJS'] = '/usr/local/phantomjs/bin/phantomjs'

"""webdriver waits for the page to finish loading, unit: second"""
sys.modules['WAIT_TIME'] = 10

"""project execution log directory"""
sys.modules['LOG_DIR'] = ''

"""excel file directory"""
sys.modules['EXCEL_DIR'] = ''



import time, os
from openpyxl import Workbook
from .config import *

class Excel():
    """This is a class that saves data to an excel file."""

    def saveFile(self, data, fileName):
        """save data to an excel file."""
        if fileName == "":
            print('file name error')
            return False
        fileDir = self.makeDir()
        if fileDir == '':
            print('file directory error')
            return False
        totalRow = len(data)
        if totalRow > 0:
            wb = Workbook()
            ws = wb.active
            for row in range(1, (totalRow + 1)):
                totalCol = len(data[(row - 1)])
                if totalCol > 0:
                    for col in range(1, (totalCol + 1)):
                        cell = ws.cell(row = row, column = col)
                        cell.value = data[(row - 1)][(col - 1)]
                else:
                    print('col data error')
                    break
            if totalCol > 0:
                wb.save(fileDir + "/" + fileName)
        else:
            print('row data error')

    def makeDir(self):
        """create a file directory"""
        localTime = time.localtime()
        month = time.strftime('%Y%m', localTime)
        day = time.strftime('%Y%m%d', localTime)
        if 'EXCEL_DIR' in globals() and EXCEL_DIR != "":
            if EXCEL_DIR[-1] == "/":
                path = EXCEL_DIR + month + "/" + day
            else:
                path = EXCEL_DIR + "/" + month + "/" + day
            if os.path.exists(path) == False:
                os.makedirs(path)
            return path
        else:
            return ''



import requests, random
from .config import *
from selenium import webdriver

class Request():
    """This is a class that handles http requests."""

    def getProxy(self):
        """get proxy ip"""
        proxy = {}
        if 'PROXY_API' in globals() and PROXY_API != '':
            req = requests.get(PROXY_API)
            ipStr = req.text
            if ipStr != '':
                ipList = ipStr.split('--')
                proxy = {ipList[2]: ipList[0] + ':' + ipList[1]}
        else:
            if 'PROXIES' in globals():
                proxyLen = len(PROXIES)
                if proxyLen > 0:
                    proxy = random.sample(PROXIES, 1)[0]
        return proxy

    def getHeader(self):
        """get client information"""
        header = {}
        if 'HEADERS' in globals():
            headerLen = len(HEADERS)
            if headerLen > 0:
                header = random.sample(HEADERS, 1)[0]
        return header

    def get(self, url, data = {}):
        """http get request"""
        req = requests.get(url, data = data, headers = self.getHeader(), proxies = self.getProxy(), timeout = TIME_OUT)

        if req.status_code == 200:
            return req.text
        else:
            print('request status code : ', req.status_code)
            return ''

    def post(self, url, data = {}):
        """http post request"""
        req = requests.post(url, data = data, headers = self.getHeader(), proxies = self.getProxy(), timeout = TIME_OUT)

        if req.status_code == 200:
            return req.text
        else:
            print('request status code : ', req.status_code)
            return ''

    def final(self, url):
        """webdriver loads webpage"""
        driver = webdriver.PhantomJS(executable_path = PHANTOMJS)
        driver.get(url)
        driver.implicitly_wait(WAIT_TIME)
        content = driver.page_source
        driver.quit()

        return content
